import { Exception } from '@angularity/core';
import { Observable } from 'rxjs';
import { ConfigFileDefinition } from './definition';
import * as i0 from "@angular/core";
/**
 * Service for loading configuration files.
 *
 * @remarks
 * By default, uses `HttpClientConfigFileLoader`
 * decorated with `CacheConfigFiles`.
 */
export declare abstract class ConfigFileLoader {
    /**
     * @returns an observable that:
     * - starts loading the configuration file according to the given definition
     * - emits the parsed configuration object
     * - completes after its first emission
     * - cancels the loading on unsubscribe before value emission
     * @throws {ConfigFileNotFoundException} if the target file is not found
     */
    abstract load<T, Schema>(def: ConfigFileDefinition<T, Schema>): Observable<T>;
    static ɵfac: i0.ɵɵFactoryDeclaration<ConfigFileLoader, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ConfigFileLoader>;
}
export declare class ConfigFileNotFoundException extends Exception {
}
